@@ -1,7 +1,9 @@
 # smtp.tcl - SMTP client
 #
 # (c) 1999-2000 Marshall T. Rose
-# Hold harmless the author, and any lawful use is allowed.
+#
+# See the file "license.terms" for information on usage and redistribution
+# of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 #
 
 
@@ -9,6 +11,19 @@ package provide smtp 1.2
 
 package require mime 1.0
 
+if {[catch {package require Trf  2.0}]} {
+    # Trf is not available, but we can live without it as long as the
+    # transform proc is defined.
+
+    # Warning!
+    # This is a fragile emulation of the more general calling sequence
+    # that appears to work with this code here.
+
+    proc transform {args} {
+	upvar state mystate
+	set mystate(size) 1
+    }
+}
 
 #
 # state variables:
@@ -170,6 +185,22 @@ proc smtp::sendmessage {part args} {
 
     if {[string compare $recipients ""]} {
         set who -recipients
+
+	# Reset To list and get rid of cc, bcc, and dcc, since -recipients
+	# overrides all of them.
+	set header($toL) $recipients
+	if {[set x [lsearch -exact $lowerL $toL]]==-1} {
+	    lappend lowerL $toL
+	    lappend mixedL $toM
+	}
+	
+	foreach elt [list $ccL $bccL $dccL] {
+	    if {[set x [lsearch -exact $lowerL $elt]]>-1} {
+		unset header($ccL)
+		set lowerL [lreplace $lowerL $x $x]
+		set mixedL [lreplace $mixedL $x $x]
+	    }
+	}
     } elseif {[catch { set recipients [smtp::merge $header($toL)] }]} {
         error "need -header \"$toM ...\""
     } else {
@@ -255,6 +286,12 @@ proc smtp::sendmessage {part args} {
                                 -multiple $bccP -queue $queueP \
                                 -servers $servers]
 
+    if {![string match "::smtp::*" $token]} {
+	# An error occurred and $token contains the error info
+	array set respArr $token
+	return -code error $respArr(diagnostic)
+    }
+
     set code [catch { smtp::sendmessageaux $token $part \
                                            $sender $vrecipients $aloP } \
                     result]
